@@ -1,21 +1,9 @@
 /*
- * Copyright © 2016-2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2016-2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2016-2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #ifndef XDG_DESKTOP_PORTAL_KDE_FILECHOOSER_H
@@ -23,8 +11,8 @@
 
 #include <QCheckBox>
 #include <QComboBox>
-#include <QDBusObjectPath>
 #include <QDBusAbstractAdaptor>
+#include <QDBusObjectPath>
 #include <QDialog>
 
 class KFileWidget;
@@ -42,6 +30,7 @@ public:
 
 private:
     QDialogButtonBox *m_buttons;
+
 protected:
     KFileWidget *m_fileWidget;
 };
@@ -97,17 +86,16 @@ public Q_SLOTS:
                   QVariantMap &results);
 
 private:
-    static QWidget* CreateChoiceControls(const OptionList& optionList,
-                                         QMap<QString, QCheckBox*>& checkboxes,
-                                         QMap<QString, QComboBox*>& comboboxes);
+    static QWidget *CreateChoiceControls(const OptionList &optionList, QMap<QString, QCheckBox *> &checkboxes, QMap<QString, QComboBox *> &comboboxes);
 
-    static QVariant EvaluateSelectedChoices(const QMap<QString, QCheckBox*>& checkboxes,
-                                            const QMap<QString, QComboBox*>& comboboxes);
+    static QVariant EvaluateSelectedChoices(const QMap<QString, QCheckBox *> &checkboxes, const QMap<QString, QComboBox *> &comboboxes);
 
     static QString ExtractAcceptLabel(const QVariantMap &options);
 
-    static void ExtractFilters(const QVariantMap &options, QStringList &nameFilters,
-                               QStringList &mimeTypeFilters, QMap<QString, FilterList> &allFilters,
+    static void ExtractFilters(const QVariantMap &options,
+                               QStringList &nameFilters,
+                               QStringList &mimeTypeFilters,
+                               QMap<QString, FilterList> &allFilters,
                                QString &selectedMimeTypeFilter);
 
     static bool isMobile();
